Documentation
¶
Overview ¶
Package usergrp maintains the group of handlers for user access.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AppNewUser ¶
type AppNewUser struct {
Name string `json:"name" validate:"required"`
Email string `json:"email" validate:"required,email"`
Roles []string `json:"roles" validate:"required"`
Department string `json:"department"`
Password string `json:"password" validate:"required"`
PasswordConfirm string `json:"passwordConfirm" validate:"eqfield=Password"`
}
AppNewUser defines the data needed to add a new user.
func (AppNewUser) Validate ¶
func (app AppNewUser) Validate() error
Validate checks the data in the model is considered clean.
type AppUpdateUser ¶
type AppUpdateUser struct {
Name *string `json:"name"`
Email *string `json:"email" validate:"omitempty,email"`
Roles []string `json:"roles"`
Department *string `json:"department"`
Password *string `json:"password"`
PasswordConfirm *string `json:"passwordConfirm" validate:"omitempty,eqfield=Password"`
Enabled *bool `json:"enabled"`
}
AppUpdateUser defines the data needed to update a user.
func (AppUpdateUser) Validate ¶
func (app AppUpdateUser) Validate() error
Validate checks the data in the model is considered clean.
type AppUser ¶
type AppUser struct {
ID string `json:"id"`
Name string `json:"name"`
Email string `json:"email"`
Roles []string `json:"roles"`
PasswordHash []byte `json:"-"`
Department string `json:"department"`
Enabled bool `json:"enabled"`
DateCreated string `json:"dateCreated"`
DateUpdated string `json:"dateUpdated"`
}
AppUser represents information about an individual user.
Click to show internal directories.
Click to hide internal directories.