Documentation
¶
Overview ¶
Package vproductgrp maintains the group of handlers for detailed product data.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type AppProduct ¶
type AppProduct struct {
ID string `json:"id"`
UserID string `json:"userID"`
Name string `json:"name"`
Cost float64 `json:"cost"`
Quantity int `json:"quantity"`
DateCreated string `json:"dateCreated"`
DateUpdated string `json:"dateUpdated"`
UserName string `json:"userName"`
}
AppProduct represents information about an individual product with extended information.
Click to show internal directories.
Click to hide internal directories.