Documentation
¶
Overview ¶
Package mux provides support to bind domain level routes to the application mux.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Config ¶
type Config struct {
Build string
Shutdown chan os.Signal
Log *logger.Logger
Delegate *delegate.Delegate
Auth *auth.Auth
DB *sqlx.DB
Tracer trace.Tracer
}
Config contains all the mandatory systems required by handlers.
type Options ¶
type Options struct {
// contains filtered or unexported fields
}
Options represent optional parameters.
type RouteAdder ¶
RouteAdder defines behavior that sets the routes to bind for an instance of the service.
Click to show internal directories.
Click to hide internal directories.